@@ -3,7 +3,7 @@ package Wikibase::Datatype::Print;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 
@@ -79,19 +79,19 @@ TODO
 
 =item L<Wikibase::Datatype::Print::Value::Globecoordinate>
 
-Wikibase globe coordinate pretty print helpers.
+Wikibase globe coordinate item pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Item>
 
-TODO
+Wikibase item value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Monolingual>
 
-TODO
+Wikibase monolingual value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Property>
 
-TODO
+Wikibase property value pretty print helpers.
 
 =item L<Wikibase::Datatype::Print::Value::Quantity>
 
@@ -143,6 +143,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
